/*
  Tutorial 7:  Nokia 5110 LCD demo 
  Description: Explore the Nokia 5110 LCD serial interface and send display data from chipKIT Uno32. 
  Board: chipKIT UNO32
        
  Connect CLK to Pin 8
  Connect DIN to Pin 9
  Connect DC to Pin 10
  Connect RST to Pin 11
  Connect CS to Pin 12
  
  Written by: Raj Bhatt (April 2014)
  www.embedded-lab.com 
  
  Uses modified DHT22 library from Trevor van der Linden,
  and Nokia 5110 LCD library for chipKIT from Rinky-Dink Electronics. 
*/

#include <LCD5110_Basic.h>
#include <DHT22.h>
// Only used for sprintf
#include <stdio.h>

// Data wire is plugged into port 7 on the Arduino
// Connect a 4.7K resistor between VCC and the data pin (strong pullup)
#define DHT22_PIN 7

LCD5110 myGLCD(8,9,10,11,12);
// Setup a DHT22 instance
DHT22 myDHT22(DHT22_PIN);

extern unsigned char SmallFont[];
char tempC[5];
char RH[5];

void setup()
{
  myGLCD.InitLCD();
  myGLCD.setFont(SmallFont);
  // start serial port
  Serial.begin(9600);
  Serial.println("DHT22 Library Demo");
}

void loop(void)
{ 
  DHT22_ERROR_t errorCode;
  myGLCD.clrScr();
   
  Serial.print("Requesting data...");
  errorCode = myDHT22.readData();
  switch(errorCode)
  {
    case DHT_ERROR_NONE:
      Serial.print("Got Data ");
      Serial.print(myDHT22.getTemperatureC());
      Serial.print("C ");
      Serial.print(myDHT22.getHumidity());
      Serial.println("%");
      myGLCD.print("Nokia 5110 LCD", 0, 0);
      myGLCD.print("Demo", 0, 11);
      sprintf(tempC, "%.1f", myDHT22.getTemperatureC());
      sprintf(RH, "%.1f", myDHT22.getHumidity());
      myGLCD.print("Temp.=", 0, 25);
      myGLCD.print(tempC, 35, 25);
      myGLCD.print("~C", 61, 25);
      myGLCD.print("Hum.=", 0, 35);
      myGLCD.print(RH, 35, 35);
      myGLCD.print("%", 61, 35);
      // Alternately, with integer formatting which is clumsier but more compact to store and
	  // can be compared reliably for equality:
	  //	  
      char buf[128];
      sprintf(buf, "Integer-only reading: Temperature %hi.%01hi C, Humidity %i.%01i %% RH",
                   myDHT22.getTemperatureCInt()/10, abs(myDHT22.getTemperatureCInt()%10),
                   myDHT22.getHumidityInt()/10, myDHT22.getHumidityInt()%10);
      Serial.println(buf);
      break;
    case DHT_ERROR_CHECKSUM:
      Serial.print("check sum error ");
      Serial.print(myDHT22.getTemperatureC());
      Serial.print("C ");
      Serial.print(myDHT22.getHumidity());
      Serial.println("%");
      break;
    case DHT_BUS_HUNG:
      Serial.println("BUS Hung ");
      break;
    case DHT_ERROR_NOT_PRESENT:
      Serial.println("Not Present ");
      break;
    case DHT_ERROR_ACK_TOO_LONG:
      Serial.println("ACK time out ");
      break;
    case DHT_ERROR_SYNC_TIMEOUT:
      Serial.println("Sync Timeout ");
      break;
    case DHT_ERROR_DATA_TIMEOUT:
      Serial.println("Data Timeout ");
      break;
    case DHT_ERROR_TOOQUICK:
      Serial.println("Polled to quick ");
      break;
  
  }
  
  delay(5000);
}

